==> haskell-dav-1.3.4-834-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-JA8Ft2W9FZ21TDs2cPJ69Y
key:                  DAV-1.3.4-JA8Ft2W9FZ21TDs2cPJ69Y
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  c710acf0bd20f5e0a6d0294ef8ef09b9
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-JA8Ft2W9FZ21TDs2cPJ69Y
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7 containers-0.6.7
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR exceptions-0.10.5
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-9DQJFK0WHcQ1sjDWa6wyhD
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP
    xml-hamlet-0.5.0.2-AiOC10eKZPCD5fBGxSDLFd

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.4-859-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-IzKxbp8zuhn3k7nKFWSrJ9
key:                  DAV-1.3.4-IzKxbp8zuhn3k7nKFWSrJ9
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  ece4f9626c696da1f0bdcb6b4f5c4b77
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-IzKxbp8zuhn3k7nKFWSrJ9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY containers-0.6.7
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi exceptions-0.10.5
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF
    xml-hamlet-0.5.0.2-9WP3rTlBIJJ2kr7ClFcHWq

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
